@@ -31,9 +31,9 @@ class DataClient:
         self.debug = debug
         self.token = os.environ["DC_TOKEN"] if "DC_TOKEN" in os.environ else token
 
-        self.get_bars = partial(self.history, data_type="bar", freq="QS", use_cache=use_cache)
+        self.get_bars = partial(self.history, data_type="bar", freq="BQS", use_cache=use_cache)
         self.get_ticks = partial(self.history, data_type="tick", freq="12BH", use_cache=use_cache)
-        self.get_dailys = partial(self.history, data_type="daily", freq="YS", use_cache=use_cache)
+        self.get_dailys = partial(self.history, data_type="daily", freq="BAS", use_cache=use_cache)
 
     def status_check(self):
         while True:
